drugParse: Parse TCGA clinical data drug information

Description Usage Arguments Value Author(s)

View source: R/drugParse.R

Description

'drugParse()' extract the drug record information from TCGA clinical XML files.

For each value in 'filenames' 'drugParse()' will extract the drug record information from clinical XML files downloaded from the TCGA database.

Usage

1
drugParse(filenames, simplify = TRUE)

Arguments

filenames

A vector contain the names of TCGA clinical XML files directorys and names (tcga_files_path/xml_file_names), which can easily retrieve by 'list.files(path = ".", pattern = "*.xml",recursive = TRUE)'. The working directorys is the key, please check the names (which contain tcga_files_path/XML_file_names) is correct.

simplify

logical, when simplify = TRUE return a tibble with patient ID information (bcr_patient_barcode, bcr_patient_uuid, tumor_tissue_site, gender), and a column contain drug names. (it's a list column, thank to the tibble freature, and it contain the patient drug names has undergone). When it's simplify = FALSE, it will return return a tibble with patient ID information (bcr_patient_barcode, bcr_patient_uuid, tumor_tissue_site, gender), and a column contain full drug record.

Value

When simplify = TRUE, return a tibble with patients id and drug names list column. When simplify = FALSE, return a tibble contain full drugs record information.

Author(s)

Fan Zhang


FanZhang9/TCGAcm documentation built on Dec. 17, 2021, 8:23 p.m.